Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8846)

Unified Diff: chrome/common/chrome_switches.cc

Issue 11316299: Enable web-based sign in flow by default. Can use command line argument (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebased Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« chrome/app/generated_resources.grd ('K') | « chrome/common/chrome_switches.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/chrome_switches.cc
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc
index be29824da375ae8f22f293a9084444bc2566d848..039aa254b8f3494fb62f5d019b6565ac6c9dc4f4 100644
--- a/chrome/common/chrome_switches.cc
+++ b/chrome/common/chrome_switches.cc
@@ -1332,8 +1332,8 @@ const char kMaxSpdyConcurrentStreams[] = "max-spdy-concurrent-streams";
// all of its state.
const char kUserDataDir[] = "user-data-dir";
-// Uses the GAIA web-based signin flow instead of the native UI signin flow.
-const char kUseWebBasedSigninFlow[] = "use-web-based-signin-flow";
+// Uses the /ClientLogin signin flow instead of the web-based signin flow.
+const char kUseClientLoginSigninFlow[] = "use-client-login-signin-flow";
// Specifies a custom URL for the server which reports variation data to the
// client. See variations_service.cc.
« chrome/app/generated_resources.grd ('K') | « chrome/common/chrome_switches.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698